==> interpretdl-0.6.0.tar.gz: interpretdl-0.6.0/interpretdl/interpreter/__init__.py <==
# Files within this path, contain the interpretation algorithms.

from .abc_interpreter import Interpreter
from .abc_interpreter import InputGradientInterpreter, InputOutputInterpreter, IntermediateLayerInterpreter

from .lime import LIMECVInterpreter, LIMENLPInterpreter
from .gradient_cam import GradCAMInterpreter
from .integrated_gradients import IntGradCVInterpreter, IntGradNLPInterpreter
from .smooth_grad import SmoothGradInterpreter
from .smooth_grad_v2 import SmoothGradInterpreterV2
from .occlusion import OcclusionInterpreter
from .gradient_shap import GradShapCVInterpreter, GradShapNLPInterpreter
from .score_cam import ScoreCAMInterpreter
from .lrp import LRPCVInterpreter
from .rollout import RolloutInterpreter
from .transition_attention_maps import TAMInterpreter
from .consensus import ConsensusInterpreter
from .generic_attention import GAInterpreter

__all__ = [
    "Interpreter", "InputGradientInterpreter", "InputOutputInterpreter", "IntermediateLayerInterpreter",
    "LIMECVInterpreter", "LIMENLPInterpreter", "GradCAMInterpreter", "IntGradCVInterpreter", "IntGradNLPInterpreter",
    "SmoothGradInterpreter", "OcclusionInterpreter", "GradShapCVInterpreter", "GradShapNLPInterpreter",
    "ScoreCAMInterpreter", "LRPCVInterpreter", "RolloutInterpreter", "TAMInterpreter", "SmoothGradInterpreterV2",
    'ConsensusInterpreter', 'GAInterpreter'
]

try:
    import paddle
    from . import lime_prior
    from .lime_prior import LIMEPriorInterpreter
    from .forgetting_events import ForgettingEventsInterpreter
    from ._normlime_base import NormLIMECVInterpreter, NormLIMENLPInterpreter
    __all__ += [
        "LIMEPriorInterpreter", "ForgettingEventsInterpreter", "NormLIMECVInterpreter", "NormLIMENLPInterpreter"
    ]
except ModuleNotFoundError:
    print("Warning: Paddle should be installed before using some Interpreters.")

==> interpretdl-0.6.2.tar.gz: interpretdl-0.6.2/interpretdl/interpreter/__init__.py <==
# Files within this path, contain the interpretation algorithms.

from .abc_interpreter import Interpreter
from .abc_interpreter import InputGradientInterpreter, InputOutputInterpreter, IntermediateLayerInterpreter

from .lime import LIMECVInterpreter, LIMENLPInterpreter
from .gradient_cam import GradCAMInterpreter
from .integrated_gradients import IntGradCVInterpreter, IntGradNLPInterpreter
from .smooth_grad import SmoothGradInterpreter
from .smooth_grad_v2 import SmoothGradInterpreterV2
from .occlusion import OcclusionInterpreter
from .gradient_shap import GradShapCVInterpreter, GradShapNLPInterpreter
from .score_cam import ScoreCAMInterpreter
from .lrp import LRPCVInterpreter
from .rollout import RolloutInterpreter
from .transition_attention_maps import TAMInterpreter
from .consensus import ConsensusInterpreter
from .generic_attention import GAInterpreter
from .bidirectional_transformer import BTInterpreter

__all__ = [
    "Interpreter", "InputGradientInterpreter", "InputOutputInterpreter", "IntermediateLayerInterpreter",
    "LIMECVInterpreter", "LIMENLPInterpreter", "GradCAMInterpreter", "IntGradCVInterpreter", "IntGradNLPInterpreter",
    "SmoothGradInterpreter", "OcclusionInterpreter", "GradShapCVInterpreter", "GradShapNLPInterpreter",
    "ScoreCAMInterpreter", "LRPCVInterpreter", "RolloutInterpreter", "TAMInterpreter", "SmoothGradInterpreterV2",
    'ConsensusInterpreter', 'GAInterpreter', 'BTInterpreter'
]

try:
    import paddle
    from .lime_prior import LIMEPriorInterpreter
    from .glime import GLIMECVInterpreter
    from .forgetting_events import ForgettingEventsInterpreter
    from ._normlime_base import NormLIMECVInterpreter, NormLIMENLPInterpreter
    __all__ += [
        "LIMEPriorInterpreter", "GLIMECVInterpreter", "ForgettingEventsInterpreter", "NormLIMECVInterpreter",
        "NormLIMENLPInterpreter"
    ]
except ModuleNotFoundError:
    print("Warning: Paddle should be installed before using some Interpreters.")
